==> arrow-docs-0.8.0-sources.jar: com/example/domain/Db$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Db`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Db`, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get()= arrow.optics.Iso(
  get = { db: `com`.`example`.`domain`.`Db` -> db.content },
  reverseGet = { `com`.`example`.`domain`.`Db`(it) }
)

inline val `com`.`example`.`domain`.`Db`.Companion.content: arrow.optics.Lens<`com`.`example`.`domain`.`Db`, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get()= arrow.optics.Lens(
  get = { db: `com`.`example`.`domain`.`Db` -> db.`content` },
  set = { value: `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`> ->
    { db: `com`.`example`.`domain`.`Db` ->
      db.copy(`content` = value)
    }
  }
)



inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Lens<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Lens<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Optional<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Optional<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Getter<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Setter<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Traversal<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Fold<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content

==> arrow-docs-0.9.0-sources.jar: com/example/domain/Db$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Db`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Db`, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get()= arrow.optics.Iso(
  get = { db: `com`.`example`.`domain`.`Db` -> db.content },
  reverseGet = { `com`.`example`.`domain`.`Db`(it) }
)

inline val `com`.`example`.`domain`.`Db`.Companion.content: arrow.optics.Lens<`com`.`example`.`domain`.`Db`, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get()= arrow.optics.Lens(
  get = { db: `com`.`example`.`domain`.`Db` -> db.`content` },
  set = { db: `com`.`example`.`domain`.`Db`, value: `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`> -> db.copy(`content` = value) }
)



inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Lens<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Lens<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Optional<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Optional<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Getter<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Setter<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Traversal<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Db`>.content: arrow.optics.Fold<S, `arrow`.`data`.`MapK`<`kotlin`.`Int`, `kotlin`.`String`>> inline get() = this + `com`.`example`.`domain`.`Db`.content
